```
Usage: vcd catalog upload [OPTIONS] <catalog-name> <file-name>

Options:
  -i, --item-name [item-name]
  -p, --progress / -n, --no-progress
                                  show progress
  -h, --help                      Show this message and exit.

```
